@@ -12,4 +12,6 @@ class Endpoint(Enum):
   LOGIN = f"{CONSUMER_URL_OLD}/login"
   ACCOUNT_INFO = f"{CONSUMER_URL_OLD}/me"
   LAST_READ = f"{CONSUMPTION_URL}/last-read"
-  CONSUMPTION_FORECAST = f"{CONSUMPTION_URL}/forecast/{{meter_id}}"
\ No newline at end of file
+  CONSUMPTION_FORECAST = f"{CONSUMPTION_URL}/forecast/{{meter_id}}"
+  DAILY_CONSUMPTION = f"{CONSUMPTION_URL}/daily/lastbillingCycle/{{meter_id}}/{{start_date}}/{{end_date}}"
+  MONTHLY_CONSUMPTION = f"{CONSUMPTION_URL}/monthly/{{meter_id}}/{{start_date}}/{{end_date}}"
